OC.L10N.register(
    "core",
    {
    "Please select a file." : "Odaberite datoteku.",
    "File is too big" : "Datoteka je prevelika",
    "The selected file is not an image." : "Odabrana datoteka nije slika.",
    "The selected file cannot be read." : "Nije moguće pročitati odabranu datoteku.",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nikakva datoteka nije učitana",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "Invalid file provided" : "Nevažeća datoteka",
    "No image or file provided" : "Nijedna slika ili datoteka nije dobavljena",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "An error occurred. Please contact your admin." : "Došlo je do pogreške. Obratite se svom administratoru.",
    "Invalid image" : "Neispravna slika",
    "No temporary profile picture available, try again" : "Slike privremenih profila nisu dostupne, pokušajte ponovno",
    "No crop data provided" : "Nema podataka o rezanju",
    "No valid crop data provided" : "Nema valjanih podataka za rezanje",
    "Crop is not square" : "Rez nije kvadrat",
    "State token does not match" : "Token stanja nije podudaran",
    "Invalid app password" : "Netočna zaporka aplikacije",
    "Could not complete login" : "Prijava nije uspjela",
    "Your login token is invalid or has expired" : "Vaš token za prijavu nije važeći ili je istekao",
    "Login" : "Prijava",
    "Password reset is disabled" : "Resetiranje zaporke je onemogućeno",
    "%s password reset" : "%s zaporka resetirana",
    "Password reset" : "Resetiranje zaporke",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknite gumb kako biste resetirali svoju zaporku. Ako niste podnijeli zahtjev za resetiranje zaporke, zanemarite ovu poruku.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknite sljedeću poveznicu kako biste resetirali svoju zaporku. Ako niste podnijeli zahtjev za resetiranje zaporke, zanemarite ovu poruku.",
    "Reset your password" : "Resetirajte svoju zaporku",
    "Nextcloud Server" : "Nextcloud poslužitelj",
    "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
    "The user limit of this instance is reached." : "Dostignuto je ograničenje broja korisnika za ovu instancu.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Unesite svoju šifru pretplate kako biste povećali ograničenje broja korisnika. Više informacija o pretplati Nextcloud Enterprise možete pronaći na našem web-mjestu.",
    "Preparing update" : "Priprema ažuriranja",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korak ispravljanja pogreške:",
    "Repair info:" : "Informacije o ispravljanju pogreške:",
    "Repair warning:" : "Upozorenje o ispravljanju pogreške:",
    "Repair error:" : "Pogreška ispravljanja pogreške:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ažurirajte putem naredbenog retka jer je automatsko ažuriranje onemogućeno u datoteci config.php.",
    "Turned on maintenance mode" : "Način rada za održavanje uključen",
    "Turned off maintenance mode" : "Način rada za održavanje isključen",
    "Maintenance mode is kept active" : "Način rada za održavanje održan",
    "Updating database schema" : "Ažuriranje sheme baze podataka",
    "Updated database" : "Baza podataka ažurirana",
    "Update app \"%s\" from App Store" : "Ažurirajte aplikaciju „%s” iz trgovine aplikacijama App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "U tijeku je provjera može li se ažurirati shema baze podataka za %s (može potrajati ovisno o veličini baze podataka)",
    "Updated \"%1$s\" to %2$s" : "Ažurirano „%1$s” u %2$s",
    "Set log level to debug" : "Postavi razinu zapisa za otklanjanje pogrešaka",
    "Reset log level" : "Resetiraj razinu zapisa",
    "Starting code integrity check" : "Početna provjera cjelovitosti koda",
    "Finished code integrity check" : "Provjera cjelovitosti koda je završena",
    "%s (incompatible)" : "%s (nije kompatibilno)",
    "The following apps have been disabled: %s" : "Sljedeće aplikacije su onemogućene: %s",
    "Already up to date" : "Nema potrebe za ažuriranjem",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vaš mrežni poslužitelj nije pravilno podešen za sinkronizaciju podataka jer je sučelje protokola WebDAV neispravno.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaš mrežni poslužitelj ne može razriješiti „{url}”. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Vaš web poslužitelj nije ispravno postavljen za razrješavanje „{url}”. To je najvjerojatnije uzrokovano konfiguracijom web-poslužitelja koja nije ažurirana i ne isporučuje izravno mapu. Usporedite svoju konfiguraciju s isporučenim pravilima za prepisivanje u „.htaccess” za Apache ili u dokumentaciji za Nginx na {linkstart}stranici s dokumentacijom ↗{linkend}. Na Nginxu su to obično linije koje počinju s „location ~” i potrebno ih je ažurirati.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Vaš web poslužitelj nije ispravno postavljen za isporuku .woff2 datoteka. To je obično problem s konfiguracijom Nginxa. Nextcloud 15 zahtijeva podešavanje za isporuku .woff2 datoteka. Usporedite svoju Nginx konfiguraciju s preporučenom konfiguracijom u našoj {linkstart}dokumentaciji ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Čini se da PHP nije ispravno postavljen za slanje upita u vezi s varijablama okruženja sustava. Ispitivanje s getenv („PATH”) vraća samo prazan odgovor.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Provjerite {linkstart}instalacijsku dokumentaciju ↗{linkend} za napomene o konfiguraciji PHP-a i konfiguraciju PHP-a na svojem poslužitelju, posebice ako upotrebljavate php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša se baza podataka ne pokreće s razinom izolacije transakcije „READ COMMITTED”. To može uzrokovati probleme kada se paralelno izvršava više radnji.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Nedostaje PHP modul „fileinfo”. Preporučujemo da omogućite ovaj modul kako biste postigli najbolje rezultate s detekcijom vrste MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Onemogućeno je zaključavanje transakcijskih datoteka što može dovesti do problema s uvjetima utrke. Omogućite „filelocking.enabled” u datoteci config.php kako biste izbjegli navedene probleme. Pogledajte {linkstart}dokumentaciju ↗{linkend} za više informacija.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Nije postavljena zadana regija telefonskih brojeva za vašu instalaciju. Potrebna je radi provjeravanja valjanosti telefonskih brojeva u postavkama profila bez pozivnog broja države. Kako biste omogućili korištenje brojeva bez pozivnog broja države dodajte „default_phone_region” s odgovarajućom {linkstart}ISO 3166-1 šifrom ↗{linkend} regije u svoju konfiguracijsku datoteku.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nije bilo moguće izvršiti cron zadatak putem sučelja komandne linije. Došlo je do sljedećih tehničkih pogrešaka:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Zadnje izvršenje zadatka u pozadini trajalo je {relativeTime}. Nešto nije u redu. {linkstart}Provjerite postavke za pozadinske zadatke ↗{linkend}.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nije konfigurirana nikakva predmemorija. Kako biste poboljšali performanse sustava, konfigurirajte predmemoriju ako je dostupna. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nije pronašao nikakav izvor nasumičnosti što nije povoljno iz sigurnosnog gledišta. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Trenutno upotrebljavate PHP {version}. Nadogradite inačicu PHP-a kako biste iskoristili {linkstart}ažuriranja performansi i sigurnosti koje isporučuje PHP Grupa ↗{linkend} čim vam vaša distribucija to omogući.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfiguracija obrnutog proxy zaglavlja je netočna ili pristupate Nextcloudu putem pouzdanog proxy poslužitelja. Ako to nije slučaj, radi se o sigurnosnom problemu koji može omogućiti napadaču da lažno predstavi svoju IP adresu koja je vidljiva Nextcloudu. Dodatne informacije možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached je konfiguriran kao distribuirana predmemorija, ali je instaliran pogrešan PHP modul „memcache”. \\OC\\Memcache\\Memcached podržava samo „memcached”, a ne „memcache”. Pogledajte {linkstart}memcached wiki za informacije o oba modula ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Neke datoteke nisu prošle provjeru cjelovitosti. Dodatne informacije o tome kako riješiti taj problem možete pronaći u {linkstart1}dokumentaciji ↗{linkend}. ({linkstart2}Popis nevažećih datoteka…{linkend} / {linkstart3}Ponovno skeniranje…{linkend})",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP-a „set_time_limit” nije dostupna. To bi moglo dovesti do zaustavljanja skripti tijekom izvršenja i prekida instalacije. Preporučuje se uključivanje ove funkcije.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaš PHP nema podršku za FreeType što može uzrokovati neispravan prikaz profilnih slika i sučelja postavki.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Nedostaje indeks „{indexName}” u tablici „{tableName}”.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
    "Missing primary key on table \"{tableName}\"." : "Nedostaje primarni ključ u tablici „{tableName}”.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "U bazi podataka nedostaju određeni primarni ključevi. Zbog činjenice da bi dodavanje primarnih ključeva moglo potrajati neko duže vrijeme u velikim tablicama, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-primary-keys” ti se primarni ključevi mogu ručno dodati dok instanca radi.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Nedostaje neobavezan stupac „{columnName}” u tablici „{tableName}”.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "U bazi podataka nedostaju određeni neobavezni stupci. Zbog činjenice da bi dodavanje stupaca u velikim tablicama moglo potrajati neko duže vrijeme, stupci se ne dodaju automatski, već je njihovo dodavanje neobavezno. Izvršenjem „occ db:add-missing-columns” ti se stupci mogu ručno dodati dok instanca radi. Nakon dodavanja stupaca može se poboljšati odaziv ili uporabljivost određenih značajki.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "U ovoj instanci nedostaju neki preporučeni moduli PHP-a. Preporučujemo da ih instalirate kako biste poboljšali performanse i ostvarili bolju kompatibilnost.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nema podršku za SVG u ovoj instanci. Preporučuje se da ga instalirate kako biste osigurali bolju kompatibilnost.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite se trenutno upotrebljava kao pozadinska baza podataka. Za veće instalacije preporučujemo da se prebacite na neku drugu pozadinsku bazu podataka.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "To se osobito preporučuje ako upotrebljavate klijent za sinkronizaciju datoteka.",
    "The PHP memory limit is below the recommended value of 512MB." : "Ograničenje memorije PHP-a ispod je preporučene vrijednosti od 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Određeni direktoriji aplikacija vlasništvo su korisnika koji nije vlasnik web poslužitelja. To se može dogoditi ako su aplikacije ručno instalirane. Provjerite dopuštenja za sljedeće direktorije aplikacija:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL se koristi kao aktivna baza podataka, ali ne podržava 4-bajtne znakove. Kako biste se mogli koristiti 4-bajtnim znakovima (primjerice, smajlići) bez problema u nazivima datoteka ili komentarima, preporučuje se da omogućite 4-bajtnu podršku u MySQL-u. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje u dokumentaciji ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ova instanca upotrebljava pohranu objekta temeljenu na S3 kao primarnu pohranu. Otpremljene datoteke privremeno se pohranjuju na poslužitelju i stoga je preporučljivo osigurati 50 GB slobodnog prostora u privremenom direktoriju PHP-a. Više informacija o putovima i dostupnom prostoru potražite u zapisima poslužitelja. Ako želite osloboditi više prostora, promijenite privremeni direktorij u datoteci php.ini ili oslobodite prostor na tom putu.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Instanci pristupate putem sigurne veze, ali instanca generira nesigurne URL-ove. To najvjerojatnije znači da se nalazite iza obrnutog proxyja i nisu točno postavljene varijable za izmjenu konfiguracijske datoteke. Pročitajte {linkstart}odgovarajuću dokumentaciju ↗{linkend}.",
    "Error occurred while checking server setup" : "Pogreška prilikom provjere postavki poslužitelja",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Više informacija potražite u {linkstart}dokumentaciji ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. Neke značajke možda neće ispravno raditi pa preporučujemo da prilagodite ovu postavku.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” ne sadrži „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP zaglavlje „{header}” nije postavljeno na „{val1}”, „{val2}”, „{val3}”, „{val4}” ili „{val5}”. Može doći do curenja informacija o uputitelju. Pogledajte {linkstart}Preporuke W3C-a ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP zaglavlje „Strict-Transport-Security” nije postavljeno na najmanje „{seconds}” sekundi. Kako biste poboljšali sigurnost sustava, preporučujemo da omogućite HSTS kao što je opisano u {linkstart}sigurnosnim savjetima ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Nesiguran pristup web-mjestu putem HTTP-a. Preporučujemo da postavite poslužitelj tako da zahtijeva korištenje HTTPS-a kao što je opisano u {linkstart}sigurnosnim savjetima ↗{linkend}.",
    "unknown text" : "nepoznati tekst",
    "Hello world!" : "Pozdrav svijete!",
    "sunny" : "sunčano",
    "Hello {name}, the weather is {weather}" : "Pozdrav {name}, vrijeme je {weather}",
    "Hello {name}" : "Pozdrav {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Rezultati vašeg pretraživanja<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["preuzimanje %n datoteke","preuzimanje %n datoteka","preuzimanje %n datoteka"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ažuriranje je u tijeku, napuštanjem ove stranice možete prekinuti postupak u nekim okruženjima.",
    "Update to {version}" : "Ažuriraj na {version}",
    "An error occurred." : "Došlo je do pogreške.",
    "Please reload the page." : "Ponovno učitajte stranicu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ažuriranje nije uspjelo. Za više informacija <a href=“{url}“>pročitajte objavu na forumu</a> koja pokriva ovaj problem.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ažuriranje nije uspjelo. Prijavite ovaj problem <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudovoj zajednici</a>.",
    "Continue to {productName}" : "Nastavite do {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekundu.","Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekunde.","Ažuriranje uspješno. Preusmjeravanje na {productName} za %n sekundi."],
    "More apps" : "Više aplikacija",
    "Log in" : "Prijava",
    "Logging in …" : "Prijavljivanje...",
    "Server side authentication failed!" : "Autentifikacija na poslužitelju nije uspjela!",
    "Please contact your administrator." : "Obratite se svom administratoru.",
    "An internal error occurred." : "Došlo je do unutarnje pogreške.",
    "Please try again or contact your administrator." : "Pokušajte ponovno ili se obratite svom administratoru.",
    "Password" : "Zaporka",
    "Wrong username or password." : "Pogrešno korisničko ime ili zaporka.",
    "User disabled" : "Korisnik je onemogućen",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Otkrili smo nekoliko nevažećih pokušaja prijave s vaše IP adrese. Iduća prijava odgađa se za najviše 30 sekundi.",
    "Username or email" : "Korisničko ime ili adresa e-pošte",
    "Your account is not setup for passwordless login." : "Nije odabrana mogućnost prijave bez zaporke za vaš račun.",
    "Browser not supported" : "Preglednik nije podržan",
    "Passwordless authentication is not supported in your browser." : "Vaš preglednik ne podržava autentifikaciju bez zaporke.",
    "Your connection is not secure" : "Vaša veza nije sigurna",
    "Passwordless authentication is only available over a secure connection." : "Autentifikacija bez zaporke dostupna je samo ako je uspostavljena sigurna veza.",
    "Reset password" : "Resetiraj zaporku",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Poslana Vam je poruka za resetiranje zaporke na adresu e-pošte za ovaj račun. Ako je niste primili, provjerite Vaše mape smeća i neželjene pošte, ili se obratite svom lokalnom administratoru.",
    "If it is not there ask your local administrator." : "Ako i tamo nema poruke, obratite se lokalnom administratoru.",
    "Couldn't send reset email. Please contact your administrator." : "Nije moguće poslati poruku za resetiranje. Kontaktirajte s administratorom.",
    "Password cannot be changed. Please contact your administrator." : "Zaporku nije moguće promijeniti. Obratite se svom administratoru.",
    "Back to login" : "Natrag na prijavu",
    "New password" : "Nova zaporka",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaši podaci su šifrirani. Ako resetirate zaporku, nećete ih moći kasnije vratiti. Ako ne znate što učiniti, obratite se svom administratoru prije nego što nastavite. Želite li nastaviti?",
    "I know what I'm doing" : "Znam što radim",
    "Resetting password" : "Resetiranje zaporke",
    "Recommended apps" : "Preporučene aplikacije",
    "Loading apps …" : "Učitavanje aplikacija…",
    "Could not fetch list of apps from the App Store." : "Dohvaćanje popisa aplikacija iz trgovine aplikacijama nije uspjelo.",
    "Installing apps …" : "Instaliranje aplikacija…",
    "App download or installation failed" : "Neuspješno preuzimanje ili instalacija aplikacije",
    "Cannot install this app because it is not compatible" : "Aplikaciju nije moguće instalirati jer nije kompatibilna",
    "Cannot install this app" : "Ovu aplikaciju nije moguće instalirati",
    "Skip" : "Preskoči",
    "Install recommended apps" : "Instaliraj preporučene aplikacije",
    "Schedule work & meetings, synced with all your devices." : "Zakažite zadatke i sastanke, sinkronizirajte ih sa svim svojim uređajima.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Čuvajte podatke o kolegama i prijateljima na jednom mjestu bez ugrožavanja njihovih osobnih informacija.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednostavna aplikacija za upravljanje e-poštom, integrirana s aplikacijama Files, Contacts i Calendar.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
    "Collaboratively edit office documents." : "Surađujte na uređivanju dokumenata paketa Office.",
    "Local document editing back-end used by the Collabora Online app." : "Pozadinski sustav za uređivanje lokalnih dokumenata u aplikaciji Collabora Online.",
    "Forgot password?" : "Zaboravili ste zaporku?",
    "Log in with a device" : "Prijavite se s pomoću uređaja",
    "Back" : "Natrag",
    "Login form is disabled." : "Obrazac za prijavu je onemogućen.",
    "Reset search" : "Resetiraj pretraživanje",
    "Search for {name} only" : "Traži samo {name}",
    "No results for {query}" : "Nema rezultata za {query}",
    "Start typing to search" : "Počnite unositi tekst za pretraživanje",
    "Loading more results …" : "Učitavanje više rezultata…",
    "Load more results" : "Učitaj više rezultata",
    "Search" : "Traži",
    "An error occurred while searching for {type}" : "Došlo je do pogreške pri traženju {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje"],
    "Search {types} …" : "Traži {types}…",
    "Settings" : "Postavke",
    "Could not load your contacts" : "Učitavanje vaših kontakata trenutno nije moguće",
    "Search contacts …" : "Pretraži kontakte...",
    "No contacts found" : "Nikakvi kontakti nisu nađeni",
    "Show all contacts …" : "Prikaži sve kontakte...",
    "Install the Contacts app" : "Instalirajte aplikaciju Kontakti",
    "Loading your contacts …" : "Učitavanje vaših kontakata...",
    "Looking for {term} …" : "Tražim {term}…",
    "No" : "Ne",
    "Yes" : "Da",
    "No files in here" : "Nema datoteka",
    "New folder" : "Nova mapa",
    "No more subfolders in here" : "Ovdje više nema podmapa",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan.",
    "\"/\" is not allowed inside a file name." : "„/” nije dopušteno unutar naziva datoteke.",
    "\"{name}\" is not an allowed filetype" : "„{name}” nije dopuštena vrsta datoteke",
    "{newName} already exists" : "{newName} već postoji",
    "Choose" : "Odaberite",
    "Copy" : "Kopiraj",
    "Move" : "Premjesti",
    "Error loading file picker template: {error}" : "Pogrešno učitavanje predloška za pronalazača datoteke: {error}",
    "OK" : "U redu",
    "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}",
    "read-only" : "samo za čitanje",
    "_{count} file conflict_::_{count} file conflicts_" : ["neželjeno podudaranje u {count} datoteci","neželjeno podudaranje u {count} datoteci","neželjeno podudaranje u {count} datoteci"],
    "One file conflict" : "Nepodudaranje datoteke",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Postojeće datoteke",
    "Which files do you want to keep?" : "Koje datoteke želite zadržati?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako odaberete obje inačice, kopirana će datoteka uz naziv imati i broj.",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "(all selected)" : "(sve odabrano)",
    "({count} selected)" : "({count} odabran)",
    "Error loading file exists template" : "Pogrešno učitavanje predloška za postojeću datoteku",
    "Pending" : "Na čekanju",
    "Copy to {folder}" : "Kopiraj u {folder}",
    "Move to {folder}" : "Premjesti u {folder}",
    "Saving …" : "Spremanje...",
    "Authentication required" : "Potrebna autentifikacija",
    "This action requires you to confirm your password" : "Za izvršavanje ove radnje potvrdite svoju zaporku",
    "Confirm" : "Potvrdi",
    "Failed to authenticate, try again" : "Pogreška pri provjeri autentičnosti, pokušajte ponovo",
    "seconds ago" : "prije nekoliko sekundi",
    "Connection to server lost" : "Izgubljena veza s poslužiteljem",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi","Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi","Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi"],
    "Add to a project" : "Dodaj projektu",
    "Show details" : "Prikaži pojedinosti",
    "Hide details" : "Sakrij pojedinosti",
    "Rename project" : "Preimenuj projekt",
    "Failed to rename the project" : "Preimenovanje projekta nije uspjelo",
    "Failed to create a project" : "Izrada projekta nije uspjela",
    "Failed to add the item to the project" : "Dodavanje stavke u projekt nije uspjelo",
    "Connect items to a project to make them easier to find" : "Povežite stavke s projektom kako biste ih lakše pronašli",
    "Type to search for existing projects" : "Upišite za pretraživanje postojećih projekata",
    "New in" : "Novo u",
    "View changelog" : "Prikaži zapis promjena",
    "Very weak password" : "Zaporka vrlo slaba",
    "Weak password" : "Zaporka Slaba",
    "So-so password" : "Zaporka prosječne jačine",
    "Good password" : "Zaporka dobra",
    "Strong password" : "Zaporka jaka",
    "No action available" : "Nikakve radnje trenutno nisu dostupne",
    "Error fetching contact actions" : "Pogreška pri dohvaćanju radnji kontakata",
    "Non-existing tag #{tag}" : "Nepostojeća oznaka #{tag}",
    "restricted" : "ograničeno",
    "invisible" : "nevidljivo",
    "Delete" : "Izbriši",
    "Rename" : "Preimenuj",
    "Collaborative tags" : "Oznake za suradnju",
    "No tags found" : "Nema pronađenih oznaka",
    "Personal" : "Osobno",
    "Users" : "Korisnici",
    "Apps" : "Aplikacije",
    "Admin" : "Administrator",
    "Help" : "Pomoć",
    "Access forbidden" : "Pristup zabranjen",
    "Back to %s" : "Natrag na %s",
    "File not found" : "Datoteka nije pronađena",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nije moguće pronaći na poslužitelju. Možda je dijeljenje izbrisano ili je isteklo?",
    "Too many requests" : "Previše zahtjeva",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
    "Error" : "Pogreška",
    "Previous" : "Prethodna",
    "Internal Server Error" : "Unutarnja pogreška poslužitelja",
    "The server was unable to complete your request." : "Poslužitelj nije u mogućnosti izvršiti vaš zahtjev.",
    "If this happens again, please send the technical details below to the server administrator." : "U slučaju da se ponovi, pošaljite sljedeće tehničke informacije administratoru poslužitelja.",
    "More details can be found in the server log." : "Više informacija možete pronaći u zapisima poslužitelja.",
    "Technical details" : "Tehničke informacije",
    "Remote Address: %s" : "Udaljena adresa: %s",
    "Request ID: %s" : "ID zahtjeva: %s",
    "Type: %s" : "Vrsta: %s",
    "Code: %s" : "Šifra: %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Red: %s",
    "Trace" : "Prati",
    "Security warning" : "Sigurnosno upozorenje",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vašem podatkovnom direktoriju i datotekama vjerojatno se može pristupiti putem interneta jer .htaccess datoteka ne radi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacije o ispravnom konfiguriranju poslužitelja potražite u <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
    "Create an <strong>admin account</strong>" : "Stvori <strong>administracijski račun</strong>",
    "Username" : "Korisničko ime",
    "Show password" : "Pokaži zaporku",
    "Toggle password visibility" : "Uključivanje/isključivanje vidljivosti zaporke",
    "Storage & database" : "Pohrana i baza podataka",
    "Data folder" : "Mapa za podatke",
    "Configure the database" : "Konfiguriraj bazu podataka",
    "Only %s is available." : "Jedino je %s dostupan.",
    "Install and activate additional PHP modules to choose other database types." : "Instalirajte i aktivirajte dodatne module PHP-a kako biste odabrali druge vrste baza podataka.",
    "For more details check out the documentation." : "Za više informacija pogledajte dokumentaciju.",
    "Database user" : "Korisnik baze podataka",
    "Database password" : "Zaporka baze podataka",
    "Database name" : "Naziv baze podataka",
    "Database tablespace" : "Tablični prostor baze podataka",
    "Database host" : "Glavno računalo baze podataka",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Navedite broj porta zajedno s nazivom računala (npr. localhost: 5432).",
    "Performance warning" : "Upozorenje o performansama",
    "You chose SQLite as database." : "Odabrali ste SQLite kao bazu podataka.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bi se trebao upotrebljavati samo za minimalne i razvojne instance. Za produkcijske instance preporučujemo korištenje neke druge pozadinske baze podataka.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ako upotrebljavate klijente za sinkronizaciju datoteka, preporučujemo izbjegavanje baze podataka SQLite.",
    "Install" : "Instaliraj",
    "Need help?" : "Treba li vam pomoć?",
    "See the documentation" : "Pogledajte dokumentaciju",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Primijetili smo da pokušavate ponovno instalirati Nextcloud. Međutim, datoteka CAN_INSTALL nedostaje iz vašeg direktorija. Stvorite datoteku CAN_INSTALL u konfiguracijskoj mapi prije nego što nastavite.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL nije moguće ukloniti iz konfiguracijske mape. Ručno uklonite ovu datoteku.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ova aplikacija zahtijeva JavaScript za ispravan rad. {linkstart}Omogućite JavaScript{linkend} i ponovno učitajte stranicu.",
    "Skip to main content" : "Preskoči na glavni sadržaj",
    "Skip to navigation of app" : "Preskoči na navigaciju aplikacije",
    "Get your own free account" : "Otvorite besplatni račun",
    "Contacts" : "Kontakti",
    "Contacts menu" : "Izbornik kontakata",
    "Confirm your password" : "Potvrdite svoju zaporku",
    "Connect to your account" : "Povežite se sa svojim računom",
    "Please log in before granting %1$s access to your %2$s account." : "Prijavite se prije odobravanja pristupa %1$s svom računu %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ako ne pokušavate postaviti novi uređaj ili aplikaciju, netko vas pokušava navesti da mu odobrite pristup svojim podacima. U tom slučaju nemojte nastaviti, već se obratite administratoru sustava.",
    "App token" : "Aplikacijski token",
    "Grant access" : "Dodijeli pristup",
    "Alternative log in using app token" : "Alternativna prijava s pomoću aplikacijskog tokena",
    "Account access" : "Pristup računu",
    "You are about to grant %1$s access to your %2$s account." : "Dopustit ćete osobi %1$s pristup vašem računu %2$s.",
    "Account connected" : "Račun povezan",
    "Your client should now be connected!" : "Vaš klijent sada bi trebao biti povezan!",
    "You can close this window." : "Možete zatvoriti ovaj prozor.",
    "This share is password-protected" : "Ovaj zajednički resurs je zaštićen zaporkom",
    "Email address" : "Adresa e-pošte",
    "Go to %s" : "Idi na %s",
    "Two-factor authentication" : "Dvofaktorska autentifikacija",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vaš račun sada je dodatno osiguran. Odaberite drugi faktor za provođenje autentifikacije:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nije moguće učitati jedan od omogućenih načina dvofaktorske autentifikacije. Obratite se svom administratoru.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dvofaktorska autentifikacija se provodi, ali nije konfigurirana na vašem računu. Obratite se administratoru za pomoć.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dvofaktorska autentifikacija se provodi, ali nije konfigurirana na vašem računu. Dovršite postavljanje dvofaktorske autentifikacije.",
    "Set up two-factor authentication" : "Postavite dvofaktorsku autentifikaciju",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dvofaktorska autentifikacija se provodi, ali nije konfigurirana na vašem računu. Prijavite se s nekom od dodatnih sigurnosnih šifri ili se obratite administratoru za pomoć.",
    "Use backup code" : "Upotrijebi pričuvnu šifru",
    "Cancel login" : "Otkaži prijavu",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Na vašem se računu provodi poboljšana sigurnost. Odaberite davatelja usluga kojeg želite primjenjivati:",
    "Error while validating your second factor" : "Pogreška prilikom potvrđivanja drugog faktora",
    "Access through untrusted domain" : "Pristup s nepouzdane domene",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Obratite se svom administratoru. Ako ste administrator, uredite postavku „trusted_domains” u datoteci config/config.php sukladno primjeru iz datoteke config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Više informacija o konfiguriranju možete pronaći u %1$sdokumentaciji%2$s.",
    "App update required" : "Ažuriranje aplikacije potrebno",
    "%1$s will be updated to version %2$s" : "%1$s će biti ažuriran na inačicu %2$s",
    "The following apps will be updated:" : "Sljedeće aplikacije bit će ažurirane:",
    "These incompatible apps will be disabled:" : "Sljedeće nekompatibilne aplikacije bit će onemogućene:",
    "The theme %s has been disabled." : "Tema %s je onemogućena.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prije nego što nastavite, osigurajte da su baza podataka, mapa konfiguracije i mapa za podatke sigurnosno kopirani.",
    "Start update" : "Započni ažuriranje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Kako biste izbjegli vremensko prekoračenje pri većim instalacijama, možete pokrenuti sljedeću naredbu iz svog instalacijskog direktorija:",
    "Detailed logs" : "Detaljni zapisnik",
    "Update needed" : "Potrebno ažurirati",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Ažurirajte putem naredbenog retka jer imate veliku instancu s više od 50 korisnika.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pomoć potražite u <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciji</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ako nastavim s ažuriranjem putem korisničkog web sučelja, postoji rizik da taj zahtjev dosegne vremensko ograničenje i dođe do gubitka podataka, ali imam sigurnosnu kopiju i znam kako vratiti instancu u slučaju problema.",
    "Upgrade via web on my own risk" : "Nadogradnja preko mreže na vlastitu odgovornost",
    "Maintenance mode" : "Način održavanja",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ova %s instanca trenutno je u načinu za održavanje; ovo može potrajati.",
    "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Provjeravanje tablice %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ovaj poslužitelj nema aktivnu internetsku vezu: nije moguće pristupiti višestrukim krajnjim točkama. To znači da neće raditi neke značajke kao što su postavljanje vanjske pohrane, obavijesti o ažuriranjima ili instalacija aplikacija treće strane. Daljinski pristup datotekama i slanje e-pošte s obavijestima također možda neće raditi. Uspostavite internetsku vezu za ovaj poslužitelj kako biste se mogli koristiti svim značajkama.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 posljednje je izdanje s podrškom za PHP 7.2. Nextcloud 21 zahtjeva najmanje PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache modul nije učitan. {linkstart}Preporučuje se da ga učitate ↗{linkend} u svoju instalaciju PHP-a kako biste poboljšali performanse.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache modul nije pravilno konfiguriran. {linkstart}Preporučuje se da ↗{linkend} koristite sljedeće postavke u datoteci <code>php.ini</code> kako biste poboljšali performanse:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "U određenim stupcima baze podataka nedostaje pretvorba u big int. Budući da promjena vrste stupca u velikim tablicama može potrajati neko duže vrijeme, stupci nisu automatski promijenjeni. Izvršenjem 'occ db:convert-filecache-bigint' te se promjene mogu ručno primijeniti. Ovu radnju morate izvršiti dok je instanca izvan mreže. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje dokumentacije ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Za prelazak na drugu bazu podataka koristite se naredbenim retkom: 'occ db:convert-type' ili pogledajte {linkstart}dokumentaciju ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Vaši direktoriji i datoteke vjerojatno su dostupni putem Interneta. Datoteka .htaccess nije u funkciji. Preporučujemo da konfigurirate web-poslužitelj tako da direktorij s podacima više nije dostupan ili premjestite direktorij s podacima izvan korijena web poslužitelja.",
    "More" : "Više",
    "More apps menu" : "Izbornik s više aplikacija",
    "Settings menu" : "Izbornik postavki",
    "The password is wrong. Try again." : "Pogrešna zaporka. Pokušajte ponovno.",
    "Setup two-factor authentication" : "Postavite dvofaktorsku autentifikaciju",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
